@@ -16,10 +16,12 @@ from linkmanager.db import DataBase
 
 app = Flask(__name__)
 assets = Environment(app)
+if settings.SERVER:
+    assets.directory = '/var/cache/linkmanager/static'
+    os.makedirs('/var/cache/linkmanager/static', mode=0o755)
 
 db = DataBase()
 
-
 # Decorator : get an Unauthorize 403 when read only's settings is True
 def read_only(func):
     def wrapper():
